@@ -6,7 +6,7 @@
 ;; Homepage: https://github.com/ahyatt/triples
 ;; Package-Requires: ((seq "2.0") (emacs "25"))
 ;; Keywords: triples, kg, data, sqlite
-;; Version: 0.1
+;; Version: 0.1.1
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
 ;; published by the Free Software Foundation; either version 2 of the
@@ -498,11 +498,11 @@ TYPE-VALS-CONS is a list of conses, combining a type and a plist of values."
 
 (defun triples-subjects-with-predicate-object (db cpred obj)
   "Return all subjects in DB with CPRED equal to OBJ."
-  (triples-db-select db nil cpred obj))
+  (mapcar #'car (triples-db-select db nil cpred obj)))
 
 (defun triples-subjects-of-type (db type)
   "Return a list of all subjects with a particular TYPE in DB."
-  (mapcar #'car (triples-subjects-with-predicate-object db 'base/type type)))
+  (triples-subjects-with-predicate-object db 'base/type type))
 
 (defun triples-combined-to-type-and-prop (combined)
   "Return cons of type and prop that form the COMBINED normal representation.
